package com.sample;

import static org.junit.Assert.assertEquals;

import java.io.File;
import java.io.FileWriter;

import org.drools.KnowledgeBase;
import org.drools.agent.KnowledgeAgent;
import org.drools.agent.KnowledgeAgentFactory;
import org.drools.io.ResourceFactory;
import org.junit.Test;

public class LoadBRL {
    @Test
    public void testSimpleBRLLoad() throws Exception
    {
        //SystemEventListenerFactory.setSystemEventListener(new PrintStreamSystemEventListener(System.out));
        File brlFile = new File("test-resources", "sample.brl");
        final String BRL_CHANGESET = 
            "<change-set xmlns=\"http://drools.org/drools-5.0/change-set\"\n" +
            "            xmlns:xs=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
            "            xs:schemaLocation=\"http://drools.org/drools-5.0/change-set http://anonsvn.jboss.org/repos/labs/labs/jbossrules/trunk/drools-api/src/main/resources/change-set-1.0.0.xsd\">\n" +
            "  <add>\n" +
            "    <resource source=\"file:" + brlFile.getAbsolutePath() + "\" type=\"BRL\" />\n" +
            "  </add>\n" +
            "</change-set>\n";
        
        File brlChangeset = new File("brlChangeset.xml");
        brlChangeset.deleteOnExit();
        writeToFile(brlChangeset, BRL_CHANGESET);
        
        KnowledgeAgent kagent = KnowledgeAgentFactory.newKnowledgeAgent("brl agent");
        kagent.applyChangeSet(ResourceFactory.newFileResource(brlChangeset));
        KnowledgeBase kbase = kagent.getKnowledgeBase();
        
        assertEquals(kbase.getKnowledgePackages().size(), 1);
        assertEquals(kbase.getKnowledgePackages().iterator().next().getRules().size(), 1);
        assertEquals(kbase.getKnowledgePackages().iterator().next().getRules().iterator().next().getName(), "sample");
        
        kagent.dispose();
    }
    
    private void writeToFile(File file, String content) throws Exception {
        FileWriter fw = null;

        try {
            fw = new FileWriter(file);
            fw.write(content);
        } finally {
            if (fw != null) fw.close();
        }
    }
}
